绿皮书 (豆瓣)
Description: 绿皮书电影简介和剧情介绍,绿皮书影评、图片、预告片、影讯、论坛、在线购票
Keywords: 绿皮书,Green Book,绿皮书影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.57豆瓣电影Top250

# 绿皮书 Green Book (2018)

导演: 彼得·法雷里
编剧: 尼克·瓦莱隆加 / 布莱恩·库瑞 / 彼得·法雷里
主演: 维果·莫腾森 / 马赫沙拉·阿里 / 琳达·卡德里尼 / 塞巴斯蒂安·马尼斯科 / 迪米特·D·马里诺夫 / 迈克·哈顿 / P·J·伯恩 / 乔·柯蒂斯 / 玛姬·尼克松 / 冯·刘易斯 / 乔恩·索特兰 / 唐·斯达克 / 安东尼·曼加诺 / 保罗·斯隆 / 珍娜·劳伦索 / 肯尼斯·以色列 / 伊克博·塞巴 / 尼克·瓦莱隆加 / 大卫·安 / 迈克·切罗内 / 杰拉尔丁·辛格 / 马丁·巴特斯·布拉德福德 / 格拉伦·布莱恩特·班克斯 / 汤姆·维图 / 夏恩·帕特洛 / 丹尼斯·W·霍尔 / 吉姆·克洛克 / 戴恩·罗兹 / 布赖恩·斯特帕尼克 / 乔恩·迈克尔·戴维斯 / 布莱恩·库瑞 / 托尼亚·马尔多纳多
类型: 剧情 / 喜剧 / 音乐 / 传记
制片国家/地区: 美国 / 中国大陆
语言: 英语 / 意大利语 / 俄语 / 德语
上映日期: 2019-03-01(中国大陆) / 2018-09-11(多伦多电影节) / 2018-11-16(美国)
片长: 130分钟
又名: 绿簿旅友(港) / 幸福绿皮书(台) / 绿书
IMDb: tt6966692
豆瓣评分
引用
8.9
1549032人评价
5星
54.9%
4星
37.5%
3星
7.1%
2星
0.4%
1星
0.1%
好于 98% 剧情片
好于 99% 喜剧片
想看 看过
评价:
推荐

## 绿皮书的剧情简介 · · · · · ·

托尼（维果·莫腾森 Viggo Mortensen 饰）是一个吊儿郎当游手好闲的混混，在一家夜总会做侍者。这间夜总会因故要停业几个月，可托尼所要支付的房租和生活费不会因此取消，所以他的当务之急是去寻找另一份工作来填补这几个月的空缺。在这个节骨眼上，一位名叫唐雪莉（马赫沙拉·阿里 Mahershala Ali 饰）的黑人钢琴家提出雇佣托尼。
唐雪莉即将开始为期八个星期的南下巡回演出，可是，那个时候南方对黑人的歧视非常的严重，于是托尼便成为了唐雪莉的司机兼保镖。一路上，两人迥异的性格使得他们之间产生了很多的矛盾，与此同时，唐雪莉在南方所遭受的种种不公平的对待也让托尼对种族歧视感到深恶痛绝。 ©豆瓣

## 绿皮书的演职员 · · · · · · ( 全部 54 )

- 彼得·法雷里 导演
- 维果·莫腾森 饰 托尼·利普 Tony Lip
- 马赫沙拉·阿里 饰 唐·雪利 Don Shirley
- 琳达·卡德里尼 饰 德洛瑞丝 Dolores
- 塞巴斯蒂安·马尼斯科 饰 约翰尼 Johnny Venere
- 迪米特·D·马里诺夫 饰 奥列格 Oleg

## 绿皮书的视频和图片 · · · · · · ( 预告片21 | 视频评论1 · 添加 | 图片1031 · 添加 )

## 绿皮书的获奖情况 · · · · · · ( 全部 )

- 第91届奥斯卡金像奖
- 最佳影片
- 查尔斯·B·韦斯勒 / 吉姆·伯克 / 尼克·瓦莱隆加 / 彼得·法雷里 / 布莱恩·库瑞

- 第76届金球奖
- 电影类 最佳音乐/喜剧片

- 第72届英国电影学院奖
- 电影奖 最佳影片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  海上钢琴师

  波西米亚狂想曲

  放牛班的春天

  爆裂鼓手

  音乐之声

  再次出发之纽约遇见你

  爱乐之城

  马戏之王

  寻梦环游记

  醉乡民谣

我要写短评

## 绿皮书的短评 · · · · · · ( 全部 379315 条 )

热门 / 最新 / 好友

### 15251 有用 王大根 看过 2019-03-01 14:36:16

肯德基年度推广大电影

### 25444 有用 陈大希 看过 2019-01-13 11:39:48

让人印象最深的片段是他们的车在南部的乡间小路上抛锚，和田里劳作的黑奴对视的那一幕，无声却发出巨响。

### 7641 有用 朝暮雪 看过 2019-01-17 11:49:44

肤色对调版《触不可及》，一场跨越美国的公路之旅，更是一场跨越种族与肤色、身份与阶层的人性之旅。 所有下属都对唐毕恭毕敬，唯有托尼把他当普通人对待，给他吃炸鸡、对他说出真实想法。 不把他当成黑人，才是真正不歧视他的表现。 另一方面，唐又受到外人的歧视和侮辱，他始终忍气吞声，低声下气。 听他演奏的观众可以在餐厅吃饭，而他作为表演者却不可以。 正是托尼教会他反击，教会他为自己发声、捍卫自己的权利和尊严。... 肤色对调版《触不可及》，一场跨越美国的公路之旅，更是一场跨越种族与肤色、身份与阶层的人性之旅。 所有下属都对唐毕恭毕敬，唯有托尼把他当普通人对待，给他吃炸鸡、对他说出真实想法。 不把他当成黑人，才是真正不歧视他的表现。 另一方面，唐又受到外人的歧视和侮辱，他始终忍气吞声，低声下气。 听他演奏的观众可以在餐厅吃饭，而他作为表演者却不可以。 正是托尼教会他反击，教会他为自己发声、捍卫自己的权利和尊严。 在所谓“高级的、尊贵的”场所受到不平等待遇，反而在“低端的、卑微的”黑人酒吧获得尊重和支持，实在太讽刺。 天才是不够的，唯有勇气才能改变人心。既然他都不考虑你的感受，你又何必照顾他的情绪呢？ 忍一时得寸进尺，退一步变本加厉。暴力不能让你赢得什么，但懦弱永远都是输家。 正面对抗生活的恶意，才能战胜恶意。 (展开)

### 7526 有用 Rocrw 看过 2018-09-12 08:48:30

绝对是今年tiff我看过的最有意思的一部电影，全场笑声掌声就没停过。节奏欢快，情节有趣又不失深度。V叔扮演的来自Bronx街头的意大利裔司机和Ali扮演的受高等教育的黑人音乐家碰撞出令人惊喜的火花，二人从纽约一路向南巡演，然而越向南种族歧视也越来越严重。导演用一种巧妙的角度向观众展示了当时的不公以及音乐家内心的纠葛。尽管他从小就在不同的重要场合表演，然而最尽兴的一次却是在圣诞前夕的一个黑人小酒吧。... 绝对是今年tiff我看过的最有意思的一部电影，全场笑声掌声就没停过。节奏欢快，情节有趣又不失深度。V叔扮演的来自Bronx街头的意大利裔司机和Ali扮演的受高等教育的黑人音乐家碰撞出令人惊喜的火花，二人从纽约一路向南巡演，然而越向南种族歧视也越来越严重。导演用一种巧妙的角度向观众展示了当时的不公以及音乐家内心的纠葛。尽管他从小就在不同的重要场合表演，然而最尽兴的一次却是在圣诞前夕的一个黑人小酒吧。他最终选择了为自己发声，不再对歧视屈服。结局温馨感人，着实是一部好电影。 (展开)

### 4980 有用 StarlightRiver 看过 2018-09-12 18:49:33

Mahershala說片子里某個根本不會被人注意到的佈景里的某塊石頭或許就是V撿的。他說V在拍攝的時候，一直留心撿很漂亮的石頭，撿到了就拿給導演說：看，把這塊石頭放在背景里會有多好看 說到電影里的部分，他可能增肥了有二三十斤，從來沒見過他有那麼大的肚腩（現在似乎已經減回來了）。今天在看V表演時，大部分的時間，我忘了他是Viggo，他就是那樣一個沒文化又油滑、滿嘴跑火車的司機。 僅僅偶爾偶爾有幾個他... Mahershala說片子里某個根本不會被人注意到的佈景里的某塊石頭或許就是V撿的。他說V在拍攝的時候，一直留心撿很漂亮的石頭，撿到了就拿給導演說：看，把這塊石頭放在背景里會有多好看 說到電影里的部分，他可能增肥了有二三十斤，從來沒見過他有那麼大的肚腩（現在似乎已經減回來了）。今天在看V表演時，大部分的時間，我忘了他是Viggo，他就是那樣一個沒文化又油滑、滿嘴跑火車的司機。 僅僅偶爾偶爾有幾個他不說話、只抽煙的鏡頭，鼻孔一噴白霧，就那麼一瞥，卻還像是十幾年前、《東方的承諾》里那個冷酷無情的殺手。 今天導演說He’s a great person before he’s a great actor. 這麼多年了，還是一直一直都沒變啊。 (展开)

> 更多短评 379315条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 绿皮书的影评 · · · · · · ( 全部 7124 条 )

热门 / 最新 / 好友
Zzzxueying 2018-12-17 08:08:31

## 你看起来像是个爱吃炸鸡的人

这篇影评可能有剧透

电影名《绿皮书》是一本历史上真实存在的黑人出行指南。在1962年，白人至上运动在美国又一次掀起小高潮，黑人邮政员维克多雨果格林编写了这么一本小册子，指出哪些旅店和餐厅可以让黑人入住和就餐。小册子的名字“Green Book”中的Green即取自格林（Green），又似乎采用了绿色... (展开)
8370 269 875回应 收起
私享史 2019-02-25 22:50:43

## 自《撞车》以来最逊的奥斯卡最佳影片

今天中午，在《绿皮书》获得奥斯卡最佳影片的那一刻，推特就炸锅了。一位黑人编剧Ira发推吐槽：“《绿皮书》？我看更像是‘白皮’书。”目前这条推已经获得超过四万个赞。接着他还说了一句：“《撞车》正在目睹《绿皮书》取代它成为最逊的奥斯卡赢家。” 美国主流媒体当然也是... (展开)
5210 1147 1628回应 收起
Herring 2019-01-13 02:01:44 #《绿皮书》和真实的事件相比，有哪些差异？

## DO and DO NOT List 关于真实的Donald Shirley

原载于 个人公众号：一只开山怪（或搜索：herringcat） 1/15/2019已更新 ----------------------------------------- 5/9再更新： 本文诸多资料均来自外网，我没有翻译的义务，我的义务是陈述我的观点。所以本文有多处英文，如果你看不懂英文，或者不习惯看英文，请不要继续阅... (展开)
2260 98 256回应 收起
梨 2019-03-10 23:35:03

## 论《绿皮书》的院线中文字幕有多少错误

二刷《绿皮书》的时候，记录了四十个字幕问题，多数是没有顾及上下文的翻译错误。低级错误的数量之多让我觉得，这部电影的字幕翻译不仅能力有限，而且不负责任。回到家以后，我整理了： 1）所有影响观众对剧情理解的错译和漏译； 2）一些虽不影响剧情理解，但拉低观感的翻译纰... (展开)
2741 25 348回应 收起
云袖舞 2019-02-26 23:38:17 #《绿皮书》有哪些有趣的设定？

## 《绿皮书》有哪些有趣的设定？

这篇影评可能有剧透

个人微信公众号：咸鱼小橘 以后的影评会首发于该微信公众号 1、接地气的炸鸡梗。Tony向Shirley强势安利黑人爱吃的炸鸡，刚开始Shirley一脸嫌弃，后来翘着兰花指吃得超享受（这一幕绝对名场面），再后来有一站巡演富丽堂皇的餐厅里端出来Shirley最爱的食物居然是炸鸡。高雅的... (展开)
4474 109 625回应 收起
破词儿 2019-01-23 09:57:25

## 你不知道的“绿皮书”背后的故事

1956年，爵士音乐人纳金高尔(Nat King Cole)受邀在美国南部的伯明翰地区为观众作表演。 台下的观众都是全白人，而纳金高尔是第一个受邀在白人机构演出的黑人，结果，他刚开始演出，就被3K党的人推下了舞台、遭到了暴烈殴打。 [绿皮书]里，当白人司机好奇唐谢利(Don Shirley)为... (展开)
1645 22 94回应 收起
Heilger 2019-01-18 09:53:52 #《绿皮书》和真实的事件相比，有哪些差异？

## 《绿皮书》和真实的事件相比，有哪些差异？

真实的 Don Shirley，不是一个远离黑人社区，不懂黑人音乐的人。他积极参与黑人民权运动，他是 Dr. King的朋友，一起参与过在Selma的游行。他和黑人音乐家 Nina Simone，Duke Ellington和Sarah Vaughn 都是极为亲密的朋友。 真实的Don Shirley，并没有跟家人疏远。电影里面说他... (展开)
577 33 162回应 收起
夜第七章 2019-02-08 09:16:24 #《绿皮书》和真实的事件相比，有哪些差异？

## 喧嚣与孤独，构成人生的全部迷局

一 列维-斯特劳斯在《忧郁的热带》写道：「有些属于过去的小细节，现在却突耸如山峰，而我自己生命里整层整层的过去却消逝无迹。一些看起来毫不相关的事件，发生于不同的地方，来源于不同的时期，都互相接触交错，突然结晶成某种纪念物。」 在《绿皮书》的最后，当我看到Don把T... (展开)
1800 23 108回应 收起
南极家暴观察员 2019-03-07 21:56:11

## 自以为是的和解

在看电影前不小心知道了一些事情，让观影过程变得很怪。比如我知道了唐·谢利家人并没有被编剧征询意见，这是法雷里和瓦莱隆加两位白人兄弟自顾自的创作，因为法雷里以为“谢利已经没有什么在世的家人了”。 然而谢利的家人是真实存在的，他们说电影是 [“a simphony of lies”... (展开)
371 29 57回应 收起
大海里的针 2019-02-28 10:30:48 #《绿皮书》与同类型种族题材电影相比有哪些不同？

## 《绿皮书》拿了奥斯卡奖，但美国黑人并不喜欢？

《绿皮书》是好莱坞今年最好的黑人电影，不服憋着！ 说的就是你——斯派克·李！ 让我们先了解下究竟发生了什么： 第91届奥斯卡的获奖名单想必大家都知道了，其中《绿皮书》拿下了最佳影片、最佳男配角、最佳原创剧本三个大奖，成为颁奖礼上最耀眼的一部影片。 借着奥斯卡的东... (展开)
485 24 67回应 收起

> 更多影评 7124篇

发起新的讨论

## 小组讨论 · · · · · ·

一部改变我三观的电影 | 来自豆瓣有意思 |  | 2022-11-20 13:29:03
为什么马赫沙拉·阿里能拿奥斯卡男配？ | 来自难得糊涂 | 9 回应 | 2022-11-15 20:36:03
影片结尾雪莉博士迈出了第一步 | 来自Auman |  | 2022-11-07 10:17:03
刚看完绿皮书，看到影评后很惊讶有一些话想说 | 来自小汪同学 | 1 回应 | 2022-10-29 20:33:35
为什么这么多人喜欢绿皮书呢，喜欢的点在哪呢？音... | 来自Jared | 31 回应 | 2022-10-26 23:17:05
中国🈶种族歧视吗 | 来自(ﾟAliceﾟ） | 20 回应 | 2022-10-26 23:05:34
豆瓣的简介为什么说是唐雪莉，一个男的为什么这么... | 来自他方天气渐凉 | 1 回应 | 2022-10-26 10:42:29
Tony竟然是指环王的Aragorn阿拉贡。。 | 来自．V | 49 回应 | 2022-10-17 20:20:12
雪莉博士是男同？？ | 来自拍不完的长镜头 | 11 回应 | 2022-10-16 18:26:08
亲爱的德洛莉丝… | 来自小蓝牙齿 | 1 回应 | 2022-10-14 23:45:57

> 去这部电影的小组讨论（全部784条）

## 关于《绿皮书》的问题 · · · · · · ( 全部66个 )

- 托尼路边解手为何要回车拿钱包？ 6人回答
- 那个石头不是放回去了吗？ 10人回答

> 全部66个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 优酷视频 VIP免费观看
- 芒果TV VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 奥斯卡最佳影片 (Boward)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 怪盗披头三【五星乱炖】 (盗三)
- IMDB TOP 250 UPDATE 20221113 (lelechen)

## 谁在看这部电影 · · · · · ·

- 豆友ZYW7_fy9t8
  1分钟前 看过
- Victor
  2分钟前 看过
- 勇敢叮当猫
  3分钟前 看过

2771887人看过 / 592249人想看

订阅绿皮书的评论:
feed: rss 2.0